################################################################################
##clusterProfiler.r
##2022-03-03 fgarcia@cipf.es
################################################################################


date ()
Sys.info ()[c("nodename", "user")]
commandArgs ()
rm (list = ls ())
R.version.string 
library (clusterProfiler); packageDescription ("clusterProfiler", fields = "Version") 
library(topGO)


set.seed(123)  #fijamos la semilla de aleatorización para el GSEA (al utilizar permutaciones,
               #fijando la semilla evitamos que cada vez el resultado pueda variar)



### A. EXAMPLE TO START
################################################################################
library(org.Hs.eg.db)
packageDescription ("org.Hs.eg.db", fields = "Version") 

# reading and explore data
data <- read.table("data/foldchange.txt", sep = "\t", as.is = T, head = T)
head(data)
dim(data)
class(data)

geneList <- data[, "FC"]
names(geneList) <-  data[, "geneID"]
class(geneList)
length(geneList)
summary(geneList)
head(geneList)

# gene selection DE (Differentially Expressed)
gene <- names(geneList)[geneList > 30 ]
length(gene)
gene.df <- bitr(gene, fromType = "SYMBOL",
                toType = c("ENSEMBL", "ENTREZID"),
                OrgDb = org.Hs.eg.db)
head(gene.df)
dim(gene.df)


## A.1. OVER REPRESENTATION ANALYSIS (ORA)
ego1 <- enrichGO(gene          = gene,
                universe      = names(geneList),
                OrgDb         = org.Hs.eg.db,
                keyType       = 'SYMBOL',
                ont           = "CC",
                pAdjustMethod = "BH",
                pvalueCutoff  = 0.01,
                qvalueCutoff  = 0.05)

head(ego1)
dim(ego1)
ego1

# ¿Cuántos CC GOs hemos evaluado en este analisis?
slotNames(ego1)  #para ver los slots individuales del objeto
dim(ego1@result) #aqui se indicara el número total de CC analizados

# ¿Cuántos CC GOs son significativos?
dim(ego1)
sig.CC <- head(ego1, nrow(ego1)) #asi guardaremos los resultados de los CC significativos en un data.frame
sig.CC  #revisa cada una de las variables incluidas en este data.frame

# visualization
dotplot(ego1, showCategory=20)
# enrichMap(ego1, vertex.label.cex=1.2, layout=igraph::layout.kamada.kawai)
cnetplot(ego1, foldChange=geneList)
plotGOgraph(ego1)



## A.2. GENE SET ENRICHMENT ANALYSIS (GSEA)
length(geneList)
head(geneList)
# we need as input a decreasing sorted vector
geneList <- sort(geneList, decreasing = T)
gsecc1 <- gseGO(geneList=geneList, ont="CC", OrgDb=org.Hs.eg.db,
                keyType = 'SYMBOL', verbose=F)
dim(gsecc1)
head(gsecc1)

# what is NES and enrichmentScore?
tail(gsecc1[,c("enrichmentScore","NES")])

#visualization
gseaplot(gsecc1, geneSetID="GO:0070469")
gseaplot(gsecc1, geneSetID="GO:0072562")



## B. EFFECT OF HORMONE T3 IN RNA-SEQ STUDY (MUS MUSCULUS)
################################################################################

library(org.Mm.eg.db)

## B.1.OVER REPRESENTATION ANALYSIS (ORA)
# B.1.1. Functional profiling for TOP genes  (high expression in T3 when comparing T3 vs. WT)
sig.top <- read.table("data/diffexp_toplist_results_t3_vs_wt.txt", 
                    sep = "\t", as.is = T) [,1]
head(sig.top)
length(sig.top)
ego2 <- enrichGO(gene          = sig.top,
                 OrgDb         = org.Mm.eg.db,
                 keyType       = 'ENSEMBL',
                 ont           = "BP",
                 pAdjustMethod = "BH",
                 pvalueCutoff  = 0.05,
                 qvalueCutoff  = 0.05)

# ¿Cuántos BP GOs hemos evaluado en este analisis?
slotNames(ego2)  #para ver los slots individuales del objeto
dim(ego2@result) #aqui se indicara el número total de BP analizados

# ¿Cuántos BP GOs son significativos?
dim(ego2)
sig.BP <- head(ego2, nrow(ego2)) #asi guardaremos los resultados de los BP significativos en un data.frame
sig.BP  #revisa cada una de las variables incluidas en este data.frame


#visualization
dotplot(ego2, showCategory=nrow(ego2))
cnetplot(ego2)
plotGOgraph(ego2)


# B.1.2.Functional profiling for BOTTOM genes  (low expression in T3 when comparing T3 vs. WT)
sig.bottom <- read.table("data/diffexp_bottomlist_results_t3_vs_wt.txt", 
                      sep = "\t", as.is = T) [,1]
head(sig.bottom)
length(sig.bottom)
ego3 <- enrichGO(gene          = sig.bottom,
                 OrgDb         = org.Mm.eg.db,
                 keyType       = 'ENSEMBL',
                 ont           = "BP",
                 pAdjustMethod = "BH",
                 pvalueCutoff  = 0.05,
                 qvalueCutoff  = 0.05)

head(ego3)
dim(ego3)
ego3

#visualization
dotplot(ego3, showCategory=20)
cnetplot(ego3)
plotGOgraph(ego3)



## B.2. GENE SET ENRICHMENT ANALYSIS (GSEA)
allgenes <- read.table("data/diffexp_t_results_ranked_t3_vs_wt.txt", 
                       sep = "\t", as.is = T)
head(allgenes)
tail(allgenes)
colnames(allgenes) <- c("geneID", "statistic")
head(allgenes)
dim(allgenes)

geneList2 <- allgenes[, "statistic"]
names(geneList2) <-  allgenes[, "geneID"]
class(geneList2)
length(geneList2)
summary(geneList2)

# we need as input a decreasing sorted vector
geneList2 <- sort(geneList2, decreasing = T)
head(geneList2)

gsecc2 <- gseGO(geneList=geneList2, ont="CC", OrgDb=org.Mm.eg.db, 
                keyType = 'ENSEMBL',verbose=F)
gsebp2 <- gseGO(geneList=geneList2, ont="BP", OrgDb=org.Mm.eg.db, 
                keyType = 'ENSEMBL',verbose=F)

dim(gsecc2)
dim(gsebp2)

head(gsecc2)
head(gsebp2)
#what is NES and enrichmentScore?
head(gsecc2[,c("enrichmentScore","NES")])
head(gsebp2[,c("enrichmentScore","NES")])
summary(gsecc2$NES)
summary(gsebp2$NES)

#visualization 
gseaplot(gsecc2, geneSetID="GO:0062023")
gseaplot(gsecc2, geneSetID="GO:0033267")




## C. RETINAL DYSTROPHIES
################################################################################

library(org.Hs.eg.db)
gene <- read.table("data/dystrophies.txt", sep = "\t", as.is = T) [,1]
head(gene)
gene.df <- bitr(gene, fromType = "SYMBOL",
                toType = c("ENTREZID", "ENSEMBL"),
                OrgDb = org.Hs.eg.db)

#Over Representation Analysis
ego2   <- enrichGO(gene         = gene.df$SYMBOL,
                 OrgDb         = org.Hs.eg.db,
                 keyType       = 'SYMBOL',
                 ont           = "CC",
                 pAdjustMethod = "BH",
                 pvalueCutoff  = 0.01,
                 qvalueCutoff  = 0.05)
head(ego3)
dim(ego3)
ego3

#visualization
dotplot(ego3, showCategory=nrow(ego3), title= "Significant CC in Retinal Dystrophies")
cnetplot(ego3, showCategory=nrow(ego3) )
plotGOgraph(ego3, firstSigNodes =nrow(ego3) )



### SAVE
save.image("clusterProfiler.results.RData")

### EXIT
warnings ()
sessionInfo ()
q ("no")
